cosmpy.protos.cosmos.mint.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.mint.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.mint.v1beta1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.mint.v1beta1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.mint.v1beta1.mint_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.mint.v1beta1.mint_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.mint.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.mint.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.mint.v1beta1.query_pb2_grpc.Query

  Bases: `object`

  Query provides defines the gRPC querier service.

  static AnnualProvisions(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Inflation(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.mint.v1beta1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query provides defines the gRPC querier service.

  AnnualProvisions(request, context)

    AnnualProvisions current minting annual provisions value.

  Inflation(request, context)

    Inflation returns the current minting inflation value.

  Params(request, context)

    Params returns the total set of minting parameters.

class cosmpy.protos.cosmos.mint.v1beta1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query provides defines the gRPC querier service.

cosmpy.protos.cosmos.mint.v1beta1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## Module contents